@@ -8,6 +8,7 @@ import xml.etree.ElementTree as ET
 #from celery import chord as celery_chord
 from io import BytesIO
 from django.conf import settings
+from django.core.files.base import ContentFile
 from django.db import transaction
 from squad.plugins import Plugin as BasePlugin
 from urllib.parse import urljoin
@@ -27,7 +28,7 @@ def update_build_status(results_list, testrun_id):
 
 
 #@celery.task
-def create_testcase_tests(test_case_string, module_name, testrun_id, suite_id):
+def create_testcase_tests(test_case_string, atomic_test_suite_name, testrun_id, suite_id):
     test_case = ET.fromstring(test_case_string)
     testrun = TestRun.objects.get(pk=testrun_id)
     suite = Suite.objects.get(pk=suite_id)
@@ -43,7 +44,6 @@ def create_testcase_tests(test_case_string, module_name, testrun_id, suite_id):
         issues[issue.test_name].append(issue)
 
     test_case_name = test_case.get("name")
-    atomic_test_suite_name = "{module_name}/{test_case_name}".format(module_name=module_name, test_case_name=test_case_name)
     tests = test_case.findall('.//Test')
     logger.debug("Extracting TestCase: {test_case_name}".format(test_case_name=test_case_name))
     logger.debug("Adding {} testcases".format(len(tests)))
@@ -228,7 +228,7 @@ class Tradefed(BasePlugin):
             #logger.debug("Creating subtasks for extracting results")
             #task_list = task_list + [create_testcase_tests.s(ET.tostring(test_case, encoding="utf-8"), module_name, testrun.pk, suite.pk) for test_case in test_cases]
             for test_case in test_cases:
-                create_testcase_tests(ET.tostring(test_case, encoding="utf-8"), module_name, testrun.pk, suite.pk)
+                create_testcase_tests(ET.tostring(test_case, encoding="utf-8"), atomic_test_suite_name, testrun.pk, suite.pk)
 
         #celery_chord(task_list)(update_build_status.s(testrun.pk))
 
@@ -429,13 +429,16 @@ class Tradefed(BasePlugin):
         logger.debug("actual file size: %s" % extracted_file.contents.tell())
         extracted_file.contents.seek(0)
 
-        testrun.attachments.create(
+        data = extracted_file.contents.read()
+        attachment = testrun.attachments.create(
             filename = name,
-            data = extracted_file.contents.read(),
+            data = data,
             length = extracted_file.length,
             mimetype = mimetype
         )
 
+        attachment.storage.save('attachment/%s/%s' % (attachment.id, name), ContentFile(data))
+
     def postprocess_testjob(self, testjob):
         # get related testjob
         logger.info("Starting CTS/VTS plugin for test job: %s" % testjob)
